# frozen_string_literal: true

def storage_validation_error(message)
  raise "#{message}. Please fix this in your gitlab.yml before starting GitLab."
end

def validate_storages_config
  if Gitlab.config.repositories.storages.empty?
    storage_validation_error('No repository storage path defined')
  end

  Gitlab.config.repositories.storages.keys.each do |name|
    # Heptapod comment to be warned by conflict if regexp changes: we
    # have to check that Gitlab::GitalyClient::VCS_QUALIFIER_SEPARATOR
    # is still prohibited by the regexp. Note that \A and \z are just
    # beginning and end of full string in Ruby regexps (stronger than ^ and $
    # that are the beginning and end of *line*).
    unless /\A[a-zA-Z0-9\-_]+\z/.match?(name)
      # Heptapod comment to be warned by conflict, as above
      storage_validation_error("\"#{name}\" is not a valid storage name")
    end
  end
end

validate_storages_config
