---
stage: none
group: Style Guide
info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://about.gitlab.com/handbook/engineering/ux/technical-writing/#assignments
description: 'Writing styles, markup, formatting, and other standards for GitLab Documentation.'
---

# A-Z word list

To help ensure consistency in the documentation, follow this guidance.

<!-- vale off -->
<!-- markdownlint-disable -->

## above

Try to avoid extra words when referring to an example or table in a documentation page, but if required, use **previously** instead.

## admin, admin area

Use **administration**, **administrator**, **administer**, or **Admin Area** instead. ([Vale](../testing.md#vale) rule: [`Admin.yml`](https://gitlab.com/gitlab-org/gitlab/-/blob/master/doc/.vale/gitlab/Admin.yml))

## allow, enable

Try to avoid, unless you are talking about security-related features. For example, instead of "This feature allows you to create a pipeline," use "Use this feature to create a pipeline." This phrasing is more active and is from the user perspective, rather than the person who implemented the feature. [View details](https://docs.microsoft.com/en-us/style-guide/a-z-word-list-term-collections/a/allow-allows).

## and/or

Instead of **and/or**, use or or rewrite the sentence to spell out both options.

## below

Try to avoid extra words when referring to an example or table in a documentation page, but if required, use **following** instead.

## currently

Do not use when talking about the product or its features. The documentation describes the product as it is today. ([Vale](../testing.md#vale) rule: [`CurrentStatus.yml`](https://gitlab.com/gitlab-org/gitlab/-/blob/master/doc/.vale/gitlab/CurrentStatus.yml))

## Developer

When writing about the Developer role, use a capital "D." Do not use the phrase, "if you are a developer"
to mean someone who is assigned the Developer role. Instead, write it out. "If you are assigned the Developer role..."

Do not use "Developer permissions." A user who is assigned the Developer role has a set of associated permissions.

## easily

Do not use. If the user doesn't find the process to be these things, we lose their trust.

## e.g.

Do not use Latin abbreviations. Use **for example**, **such as**, **for instance**, or **like** instead. ([Vale](../testing.md#vale) rule: [`LatinTerms.yml`](https://gitlab.com/gitlab-org/gitlab/-/blob/master/doc/.vale/gitlab/LatinTerms.yml))

## future tense

When possible, use present tense instead. For example, use `after you execute this command, GitLab displays the result` instead of `after you execute this command, GitLab will display the result`. ([Vale](../testing.md#vale) rule: [`FutureTense.yml`](https://gitlab.com/gitlab-org/gitlab/-/blob/master/doc/.vale/gitlab/FutureTense.yml))

## GitLab

Do not make possessive (GitLab's). This guidance follows [GitLab Brand Guidelines](https://about.gitlab.com/handbook/marketing/corporate-marketing/brand-activation/brand-guidelines/#trademark).

## Guest

When writing about the Guest role, use a capital "G." Do not use the phrase, "if you are a guest"
to mean someone who is assigned the Guest role. Instead, write it out. "If you are assigned the Guest role..."

Do not use "Guest permissions." A user who is assigned the Guest role has a set of associated permissions.

## handy

Do not use. If the user doesn't find the process to be these things, we lose their trust.

## high availability, HA

Do not use. Instead, direct readers to the GitLab [reference architectures](../../../administration/reference_architectures/index.md) for information about configuring GitLab for handling greater amounts of users.

## I

Do not use first-person singular. Use **you**, **we**, or **us** instead. ([Vale](../testing.md#vale) rule: [`FirstPerson.yml`](https://gitlab.com/gitlab-org/gitlab/-/blob/master/doc/.vale/gitlab/FirstPerson.yml))

## i.e.

Do not use Latin abbreviations. Use **that is** instead. ([Vale](../testing.md#vale) rule: [`LatinTerms.yml`](https://gitlab.com/gitlab-org/gitlab/-/blob/master/doc/.vale/gitlab/LatinTerms.yml))

## Maintainer

When writing about the Maintainer role, use a capital "M." Do not use the phrase, "if you are a maintainer"
to mean someone who is assigned the Maintainer role. Instead, write it out. "If you are assigned the Maintainer role..."

Do not use "Maintainer permissions." A user who is assigned the Maintainer role has a set of associated permissions.

## may, might

**Might** means something has the probability of occurring. **May** gives permission to do something. Consider **can** instead of **may**.

## me, myself, mine

Do not use first-person singular. Use **you**, **we**, or **us** instead. ([Vale](../testing.md#vale) rule: [`FirstPerson.yml`](https://gitlab.com/gitlab-org/gitlab/-/blob/master/doc/.vale/gitlab/FirstPerson.yml))

## Owner

When writing about the Owner role, use a capital "M." Do not use the phrase, "if you are an owner"
to mean someone who is assigned the Owner role. Instead, write it out. "If you are assigned the Owner role..."

Do not use "Owner permissions." A user who is assigned the Owner role has a set of associated permissions.

## permissions

Do not use roles and permissions interchangeably. Each user is assigned a role. Each role includes a set of permissions.

## please

Do not use. For details, see the [Microsoft style guide](https://docs.microsoft.com/en-us/style-guide/a-z-word-list-term-collections/p/please).

## profanity

Do not use. Doing so may negatively affect other users and contributors, which is contrary to the GitLab value of [Diversity, Inclusion, and Belonging](https://about.gitlab.com/handbook/values/#diversity-inclusion).

## Reporter

When writing about the Reporter role, use a capital "R." Do not use the phrase, "if you are a reporter"
to mean someone who is assigned the Reporter role. Instead, write it out. "If you are assigned the Reporter role..."

Do not use "Reporter permissions." A user who is assigned the Reporter role has a set of associated permissions.

## roles

Do not use roles and permissions interchangeably. Each user is assigned a role. Each role includes a set of permissions.

## scalability

Do not use when talking about increasing GitLab performance for additional users. The words scale or scaling are sometimes acceptable, but references to increasing GitLab performance for additional users should direct readers to the GitLab [reference architectures](../../../administration/reference_architectures/index.md) page.

## simply

Do not use. If the user doesn't find the process to be these things, we lose their trust.

## slashes

Instead of **and/or**, use **or** or another sensible construction. This rule also applies to other slashes, like **follow/unfollow**. Some exceptions (like **CI/CD**) are allowed.

## subgroup

Use instead of `sub-group`.

## that

Do not use. Example: `the file that you save` can be `the file you save`.

## useful

Do not use. If the user doesn't find the process to be these things, we lose their trust.

## utilize

Do not use. Use **use** instead. It's more succinct and easier for non-native English speakers to understand.

## via

Do not use Latin abbreviations. Use **with**, **through**, or **by using** instead. ([Vale](../testing.md#vale) rule: [`LatinTerms.yml`](https://gitlab.com/gitlab-org/gitlab/-/blob/master/doc/.vale/gitlab/LatinTerms.yml))

<!-- vale on -->
<!-- markdownlint-enable -->
