# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Project and Repository models with vcs_type="hg_git"', factory_default: :keep do
  let(:project) do
    allow_next_instance_of(Project) do |project|
      allow(project).to receive(:check_vcs_type).and_return(true)
    end
    create(:hg_git_project)
  end

  let(:raw_repo) { project.repository.raw_repository }

  describe 'raw repository' do
    context 'when fully native mode is instance-wide disabled' do
      before do
        # all feature flags, including the fallback are enabled by default
        # in RSpec tests
        stub_feature_flags(hg_fully_native: false)
      end

      it 'is not HGitaly1' do
        # actually project.hgitaly1? is true, but that is irrelevant
        expect(raw_repo).to be_instance_of(Gitlab::Mercurial::HgGitRepository)
        expect(raw_repo).not_to be_instance_of(Gitlab::Mercurial::HgitalyRepository)
        expect(raw_repo.hgitaly1?).to be(false)
      end
    end
  end
end
