# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Project and Repository models with vcs_type="hg"', factory_default: :keep do
  let(:project) do
    allow_next_instance_of(Project) do |project|
      allow(project).to receive(:check_vcs_type).and_return(true)
    end
    create(:native_hg_project)
  end

  let(:raw_repo) { project.repository.raw_repository }

  describe '#hgitaly1?' do
    context 'when fully native mode is instance-wide enabled' do
      before do
        # all feature flags, including the fallback are enabled by default in RSpec tests
        stub_feature_flags(hg_fully_native: true,
                           hgitaly1_fallback: false)
      end

      it 'is not HGitaly1 if fallback is not enabled' do
        expect(project.hgitaly1?).to be(false)
        expect(raw_repo).to be_instance_of(Gitlab::Mercurial::HgitalyRepository)
        expect(raw_repo.hgitaly1?).to be_falsey
      end

      it 'is HGitaly1 if fallback is enabled' do
        stub_feature_flags(hgitaly1_fallback: true)
        expect(project.hgitaly1?).to be(true)
        expect(raw_repo).to be_instance_of(Gitlab::Mercurial::HgitalyRepository)
        expect(raw_repo.hgitaly1?).to be(true)
      end
    end

    context 'when fully native mode is instance-wide disabled' do
      before do
        # all feature flags, including the fallback are enabled by default
        # in RSpec tests, we don't want it to interfere
        stub_feature_flags(hg_fully_native: false,
                           hgitaly1_fallback: false)
      end

      it 'is HGitaly1' do
        stub_feature_flags(hgitaly1_fallback: true)
        expect(project.hgitaly1?).to be(true)
        expect(raw_repo).to be_instance_of(Gitlab::Mercurial::HgitalyRepository)
        expect(raw_repo.hgitaly1?).to be(true)
      end
    end
  end
end
